package com.persagy.apm.alarmservice.group.alarmrecord.controller;

import com.persagy.apm.alarmservice.dependency.saasweb.service.SaasWebClientWrapper;
import com.persagy.apm.alarmservice.group.alarmrecord.model.ConvertAlarmCommentTool;
import com.persagy.apm.alarmservice.group.alarmrecord.model.dto.CreateAlarmCommentDTO;
import com.persagy.apm.alarmservice.group.alarmrecord.model.dto.PageQueryAlarmCommentDTO;
import com.persagy.apm.alarmservice.group.alarmrecord.model.vo.AlarmCommentListItem;
import com.persagy.apm.alarmservice.group.alarmrule.service.IGroupAlarmRuleService;
import com.persagy.apm.common.model.vo.SimpleObjVO;
import com.persagy.apm.common.response.ApmResponseUpsertVO;
import com.persagy.apm.common.response.CommonResult;
import com.persagy.apm.common.response.PageList;
import com.persagy.apm.common.utils.ResultHelper;
import com.persagy.apm.energyalarmstarter.alarmdata.feign.DmpResult;
import com.persagy.apm.energyalarmstarter.alarmdata.model.dto.alarmcomment.QueryAlarmCommentDTO;
import com.persagy.apm.energyalarmstarter.alarmdata.model.dto.alarmconfig.AddAlarmCommentDTO;
import com.persagy.apm.energyalarmstarter.alarmdata.model.dto.alarmitem.QueryAlarmItemDTO;
import com.persagy.apm.energyalarmstarter.alarmdata.model.dto.common.QueryDTO;
import com.persagy.apm.energyalarmstarter.alarmdata.model.vo.AlarmCommentItem;
import com.persagy.apm.energyalarmstarter.alarmdata.model.vo.AlarmItem;
import com.persagy.apm.energyalarmstarter.alarmdata.model.vo.DmpUpsertVO;
import com.persagy.apm.energyalarmstarter.alarmdata.service.AlarmCommentServiceImpl;
import com.persagy.apm.energyalarmstarter.alarmdata.service.AlarmItemServiceImpl;
import com.persagy.common.exception.BusinessException;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.assertj.core.util.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 报警类型控制层
 *
 * @author lixing
 * @version V1.0 2021-09-08 22:30:38
 */
@Api(tags = "报警类型")
@Validated
@RestController
@RequestMapping("alarm_items")
public class AlarmItemController {
    @Autowired
    AlarmItemServiceImpl alarmItemService;

    @Autowired
    private IGroupAlarmRuleService groupAlarmRuleService;

    @ApiOperation(value = "报警类型列表")
    @PostMapping("/query")
    public CommonResult<PageList<SimpleObjVO>> queryAlarmItem(
            @Valid @RequestBody QueryAlarmItemDTO queryAlarmItemDTO) throws Exception {
        DmpResult<List<AlarmItem>> dmpResult = alarmItemService.query(queryAlarmItemDTO);
        if (dmpResult == null || dmpResult.getData() == null) {
            throw new BusinessException("查询报警类型列表发生异常");
        }
        List<SimpleObjVO> resultList = dmpResult.getData().stream().map(
                alarmItem -> new SimpleObjVO(alarmItem.getCode(), alarmItem.getName())
        ).collect(Collectors.toList());
        return ResultHelper.multi(resultList);
    }
}

